library empirical_universe;

import 'dart:html';
import 'dart:math';
import '../../lib/empirical.dart';

part 'universe.dart';

main() {
  new EmpiricalUniverse();
}

const CUSTOM_MAIN = const MainMenu('''<h1>Empirical Universe - Dev: 1.2</h1>
    <a id="startbutton">Start</a>
    <a id="optionsbutton">Options</a>
    <a id="exitbutton">Exit</a>''');

const CUSTOM_PAUSE = const PauseMenu('''<h1>Universe Paused</h1>
    <a id="pausebutton">Resume</a>
    <a id="exitbutton">Exit</a>''');

const CUSTOM_OPTIONS = const OptionsMenu('''<h1>Options</h1>
    <form action="">
    Disease Spread Ticks: <select id="ticksdisease" name="ticksdisease">
    <option value="5">5</option>
    <option value="10">10</option>
    <option value="20">20</option>
    <option value="30" selected>30</option>
    </select>

    Infection Rate: <select id="infectionrate" name="infectionrate">
    <option value="annoying" selected>Annoying</option>
    <option value="parasitic">Parasitic</option>
    <option value="demonic">Demonic</option>
    </select>

    Mutation Rate: <select id="mutationrate" name="mutationrate">
    <option value="annoying" selected>Annoying</option>
    <option value="parasitic">Parasitic</option>
    <option value="demonic">Demonic</option>
    </select>
    </form>
    <a id="exitbutton">Back</a>''');

class EmpiricalUniverse extends Empirical {
  final universe = new Universe();
  var tick = 0;
  var ticksDisease = 20;
  
  loadInterface() {
    replaceMenu(MAIN, CUSTOM_MAIN);
    replaceMenu(PAUSE, CUSTOM_PAUSE);
    replaceMenu(OPTIONS, CUSTOM_OPTIONS);
    super.loadInterface();
  }

  drawGame() {
    universe.draw();
  }

  startGame() {
    var dropDown = query('#ticksdisease');
    ticksDisease = int.parse(dropDown.options[dropDown.selectedIndex].value);
    
    var infectionDropDown = query('#infectionrate');
    var infection = infectionDropDown.options[infectionDropDown.selectedIndex].value;
    
    var mutationDropDown = query('#mutationrate');
    var mutation = mutationDropDown.options[mutationDropDown.selectedIndex].value;
    
    universe.generateUniverse(infectionRate: infection, mutationRate: mutation);
  }
  
  endGame() {
    universe.destroyUniverse();
    tick = 0;
  }
  
  pauseGame() {
    
  }
  
  restartGame() {
    universe.generateUniverse();
  }
  
  resizeGame() {
    universe.resize();
  }
  
  tickGame() {
    tick += 1;
    if (tick == ticksDisease) {
      universe.generateUniverse();
      tick = 0;
    }
  }
  
  keyDownGame(keyCode) {
    
  }
  
  clickGame(num x, num y) {
    int locX = (x / universe.tileWidth).floor();
    int locY = (y / universe.tileHeight).floor();
    int index = (locY * width) + locX;
    universe.click(index);
  }
  
}